/*
  Rhino test framework

   Copyright (C) 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

package org.RhinoTests.Reporter;



import java.util.Arrays;
import java.util.Set;
import java.util.TreeSet;

/**
 * Instances of this class are used to store all command line parameters.
 * 
 * @author Pavel Tisnovsky
 */
public class CommandLineParameters {
    private static final String PARAM_NAME_TEST_PREFIX = "-tests=";
    
    private static final String PARAM_NAME_DATE_PREFIX = "-date=";
    
    private static final String PARAM_NAME_REPORT_DIR_PREFIX = "-report-dir=";
    
    private static final String PARAM_NAME_LOG_DIR_PREFIX = "-log-dir=";
    
    private static final String PARAM_NAME_TEMPLATE_DIR_PREFIX = "-template-dir=";
    
    private String templateDir = null;
    private String logDir = null;
    private String reportDir = null;
    private String date = null;
    private Set<String> tests = new TreeSet<String>();

    /**
     * Constructor which starts processing all command line parameters.
     * 
     * @param args
     *            command line parameters stored as a array of Strings
     */
    public CommandLineParameters(String[] args)
    {
        processAllArgs(args);
        checkAllArgs();
    }

    /**
     * Process all command line parameters.
     * 
     * @param args
     *            command line parameters stored as a array of Strings
     */
    private void processAllArgs(String[] args) {
        for (String arg : args)
        {
            if (arg.startsWith(PARAM_NAME_TEMPLATE_DIR_PREFIX)) {
                this.templateDir = arg.substring(PARAM_NAME_TEMPLATE_DIR_PREFIX.length());
            }
            else if (arg.startsWith(PARAM_NAME_LOG_DIR_PREFIX)) {
                this.logDir = arg.substring(PARAM_NAME_LOG_DIR_PREFIX.length());
            }
            else if (arg.startsWith(PARAM_NAME_REPORT_DIR_PREFIX)) {
                this.reportDir = arg.substring(PARAM_NAME_REPORT_DIR_PREFIX.length());
            }
            else if (arg.startsWith(PARAM_NAME_DATE_PREFIX)) {
                this.date = arg.substring(PARAM_NAME_DATE_PREFIX.length());
            }
            else if (arg.startsWith(PARAM_NAME_TEST_PREFIX)) {
                String testString = arg.substring(PARAM_NAME_TEST_PREFIX.length());
                String[] testArray = testString.split(" ");
                this.tests.addAll(Arrays.asList(testArray));
            }
        }
    }

    /**
     * Basic check if all arguments are correct.
     */
    private void checkAllArgs() {
        checkTemplateDir();
        checkLogDir();
        checkReportDir();
        checkDate();
        checkTestSet();
    }

    private void checkTemplateDir() {
        if (this.templateDir == null) {
            throw new RuntimeException("template dir is not set");
        }
    }

    private void checkLogDir() {
        if (this.logDir == null) {
            throw new RuntimeException("log dir is not set");
        }
    }

    private void checkReportDir() {
        if (this.reportDir == null) {
            throw new RuntimeException("report dir is not set");
        }
    }

    private void checkDate() {
        if (this.date == null) {
            throw new RuntimeException("date is not set");
        }
    }

    private void checkTestSet() {
        if (this.tests.isEmpty()) {
            throw new RuntimeException("test list are not set");
        }
    }

    public String getLogDir() {
        return this.logDir;
    }

    public String getDate() {
        return this.date;
    }

    public String getTemplateDir() {
        return this.templateDir;
    }

    public String getReportDir() {
        return this.reportDir;
    }

    public Set<String> getTests() {
        return this.tests;
    }
}
